==> 0.10.1.tar.gz: lib/coupons_module/couponlistitem.dart <==
import 'package:cached_network_image/cached_network_image.dart';

import 'package:flutter/material.dart';

import '../models/couponenums.dart';
import '../utils/basicInfo.dart';
import '../utils/colors.dart';
import '../utils/hexColors.dart';
import '../utils/localization.dart';
import '../utils/text_styling.dart';


// ignore: must_be_immutable
class CouponListItemCard extends StatelessWidget {
  String? imageUrl;
  String? title;
  int? discount;
  int? rewardPoints;
  String? validTill;
  String? discountType;
  bool? isActive = false;
  bool? isDividerHide = false;
  bool? isCoinsHide;
  late TextStyleElements styleElements;
  double? imageWidth;
  double? imageHeight;
  BasicInfo? basicInfo = BasicInfo();
  CouponListItemCard(
      {this.imageUrl,
      this.title,
      this.discount,
      this.discountType,
      this.rewardPoints,
      this.validTill,
      this.isActive,
      this.isDividerHide,
      this.isCoinsHide,
      this.imageWidth,
      this.imageHeight});

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return Container(
      padding: EdgeInsets.all(0),
      width: double.infinity,
      child: Row(
        mainAxisSize: MainAxisSize.min,
        mainAxisAlignment: MainAxisAlignment.start,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Container(
            margin: EdgeInsets.only(right: 4),
            width: imageWidth,
            height: imageHeight,
            decoration: BoxDecoration(
              shape: BoxShape.rectangle,
              borderRadius: BorderRadius.circular(12),
              image: DecorationImage(
                fit: BoxFit.cover,
                image: CachedNetworkImageProvider(basicInfo!.baseUrl + imageUrl!),
              ),
            ),
          ),
          Visibility(
            visible: isDividerHide != null ? !isDividerHide! : true,
            child: VerticalDivider(
              thickness: 2,
              color: HexColor(AppColors.appColorBlack35),
              indent: 4,
              endIndent: 4,
            ),
          ),
          Expanded(
            child: Padding(
              padding: const EdgeInsets.only(
                  top: 8.0, bottom: 4.0, right: 4.0, left: 8.0),
              child: Column(
                mainAxisSize: MainAxisSize.min,
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.start,
                // direction: Axis.vertical,
                // crossAxisAlignment: WrapCrossAlignment.start,
                children: [
                  Padding(
                    padding: const EdgeInsets.only(top: 1.0, bottom: 1.0),
                    child: Text(
                      title!,
                      style: styleElements.headline6ThemeScalable(context),
                    ),
                  ),
                  getPriceWidget(context),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.end,
                    children: [
                      Flexible(
                        child: Padding(
                          padding: const EdgeInsets.only(right: 8.0),
                          child: Text(
                            "Expires: $validTill",
                            style: styleElements.captionThemeScalable(context),
                            maxLines: 1,
                          ),
                        ),
                      ),
                    ],
                  ),
                ],
              ),
            ),
          ),
        ],
      ),
    );
  }

  getPriceWidget(BuildContext context) {
    return Row(
      mainAxisSize: MainAxisSize.min,
      crossAxisAlignment: CrossAxisAlignment.center,
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Visibility(
          visible: discountType == COUPON_DISCOUNT_TYPE.Amount.type,
          child: Text(
            AppLocalizationsRewards.of(context)!.translate('rupee_symbol'),
            style: styleElements.headline6ThemeScalable(context),
          ),
        ),
        Padding(
          padding: const EdgeInsets.only(left: 0.0),
          child: Text(
            discount != null ? discount.toString() : "",
            style: styleElements.headline4ThemeScalable(context),
          ),
        ),
        Visibility(
          visible: discountType == COUPON_DISCOUNT_TYPE.Percentage.type,
          child: Padding(
            padding: const EdgeInsets.only(left: 4.0, right: 8.0),
            child: Text(
              "%",
              style: styleElements.headline6ThemeScalable(context),
            ),
          ),
        ),
        Text(
          (isCoinsHide != null && isCoinsHide!)
              ? ""
              : "@$rewardPoints app coins",
          style: styleElements.captionThemeScalable(context),
        )
        // Text(
        //   "Coupon",
        //   style: styleElements.captionThemeScalable(context),
        // ),
      ],
    );
  }
}

==> 0.11.1.tar.gz: lib/coupons_module/couponlistitem.dart <==
import 'package:cached_network_image/cached_network_image.dart';

import 'package:flutter/material.dart';

import '../models/couponenums.dart';
import '../utils/basicInfo.dart';
import '../utils/colors.dart';
import '../utils/hexColors.dart';
import '../utils/localization.dart';
import '../utils/text_styling.dart';

// ignore: must_be_immutable
class CouponListItemCard extends StatelessWidget {
  String? imageUrl;
  String? title;
  int? discount;
  int? rewardPoints;
  String? validTill;
  String? discountType;
  bool? isActive = false;
  bool? isDividerHide = false;
  bool? isCoinsHide;
  late TextStyleElements styleElements;
  double? imageWidth;
  double? imageHeight;
  BasicInfo? basicInfo = BasicInfo();

  CouponListItemCard(
      {this.imageUrl,
      this.title,
      this.discount,
      this.discountType,
      this.rewardPoints,
      this.validTill,
      this.isActive,
      this.isDividerHide,
      this.isCoinsHide,
      this.imageWidth,
      this.imageHeight});

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return Container(
      padding: EdgeInsets.all(0),
      width: double.infinity,
      child: Row(
        mainAxisSize: MainAxisSize.min,
        mainAxisAlignment: MainAxisAlignment.start,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Container(
            margin: EdgeInsets.only(right: 4),
            width: imageWidth,
            height: imageHeight,
            decoration: BoxDecoration(
              shape: BoxShape.rectangle,
              borderRadius: BorderRadius.circular(12),
              image: DecorationImage(
                fit: BoxFit.cover,
                image:
                    CachedNetworkImageProvider(basicInfo!.baseUrl + imageUrl!),
              ),
            ),
          ),
          Visibility(
            visible: isDividerHide != null ? !isDividerHide! : true,
            child: VerticalDivider(
              thickness: 2,
              color: HexColor(AppColors.appColorBlack35),
              indent: 4,
              endIndent: 4,
            ),
          ),
          Expanded(
            child: Padding(
              padding: const EdgeInsets.only(
                  top: 8.0, bottom: 4.0, right: 4.0, left: 8.0),
              child: Column(
                mainAxisSize: MainAxisSize.min,
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.start,
                // direction: Axis.vertical,
                // crossAxisAlignment: WrapCrossAlignment.start,
                children: [
                  Padding(
                    padding: const EdgeInsets.only(top: 1.0, bottom: 1.0),
                    child: Text(
                      title!,
                      style: styleElements.headline6ThemeScalable(context),
                    ),
                  ),
                  getPriceWidget(context),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.end,
                    children: [
                      Flexible(
                        child: Padding(
                          padding: const EdgeInsets.only(right: 8.0),
                          child: Text(
                            "Expires: $validTill",
                            style: styleElements.captionThemeScalable(context),
                            maxLines: 1,
                          ),
                        ),
                      ),
                    ],
                  ),
                ],
              ),
            ),
          ),
        ],
      ),
    );
  }

  getPriceWidget(BuildContext context) {
    return Row(
      mainAxisSize: MainAxisSize.min,
      crossAxisAlignment: CrossAxisAlignment.center,
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Visibility(
          visible: discountType == COUPON_DISCOUNT_TYPE.Amount.type,
          child: Text(
            AppLocalizationsRewards.of(context)!.translate('rupee_symbol'),
            style: styleElements.headline6ThemeScalable(context),
          ),
        ),
        Padding(
          padding: const EdgeInsets.only(left: 0.0),
          child: Text(
            discount != null ? discount.toString() : "",
            style: styleElements.headline4ThemeScalable(context),
          ),
        ),
        Visibility(
          visible: discountType == COUPON_DISCOUNT_TYPE.Percentage.type,
          child: Padding(
            padding: const EdgeInsets.only(left: 4.0, right: 8.0),
            child: Text(
              "%",
              style: styleElements.headline6ThemeScalable(context),
            ),
          ),
        ),
        Text(
          (isCoinsHide != null && isCoinsHide!)
              ? ""
              : "@$rewardPoints app coins",
          style: styleElements.captionThemeScalable(context),
        )
        // Text(
        //   "Coupon",
        //   style: styleElements.captionThemeScalable(context),
        // ),
      ],
    );
  }
}
